==> process-optaplanner-springboot-1.3.0.Final-sources.jar: org/kie/kogito/handlers/FlightService_addPassengerToFlight_16_Handler.java <==
package org.kie.kogito.handlers;

import org.kie.kogito.process.workitem.WorkItemExecutionError;

@org.springframework.stereotype.Component()
public class FlightService_addPassengerToFlight_16_Handler implements org.kie.kogito.internal.process.runtime.KogitoWorkItemHandler {

    org.kie.kogito.examples.service.FlightService service;

    public FlightService_addPassengerToFlight_16_Handler() {
        this(new org.kie.kogito.examples.service.FlightService());
    }

    @org.springframework.beans.factory.annotation.Autowired()
    @org.springframework.context.annotation.Lazy()
    public FlightService_addPassengerToFlight_16_Handler(org.kie.kogito.examples.service.FlightService service) {
        this.service = service;
    }

    public void executeWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
        java.lang.Object result;
        result = service.addPassengerToFlight((org.kie.kogito.examples.domain.Flight) workItem.getParameter("flight"), (org.kie.kogito.examples.domain.PassengerDTO) workItem.getParameter("passenger"));
        workItemManager.completeWorkItem(workItem.getStringId(), java.util.Collections.singletonMap("flight", result));
    }

    public void abortWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
    }

    public String getName() {
        return "org.kie.kogito.examples.service.FlightService_addPassengerToFlight_16_Handler";
    }
}

==> process-optaplanner-springboot-1.8.0.Final-sources.jar: org/kie/kogito/handlers/FlightService_addPassengerToFlight_16_Handler.java <==
package org.kie.kogito.handlers;

import org.kie.kogito.process.workitem.WorkItemExecutionException;

@org.springframework.stereotype.Component()
public class FlightService_addPassengerToFlight_16_Handler implements org.kie.kogito.internal.process.runtime.KogitoWorkItemHandler {

    org.kie.kogito.examples.service.FlightService service;

    public FlightService_addPassengerToFlight_16_Handler() {
        this(new org.kie.kogito.examples.service.FlightService());
    }

    @org.springframework.beans.factory.annotation.Autowired()
    @org.springframework.context.annotation.Lazy()
    public FlightService_addPassengerToFlight_16_Handler(org.kie.kogito.examples.service.FlightService service) {
        this.service = service;
    }

    public void executeWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
        java.lang.Object result;
        result = service.addPassengerToFlight((org.kie.kogito.examples.domain.Flight) workItem.getParameter("flight"), (org.kie.kogito.examples.domain.PassengerDTO) workItem.getParameter("passenger"));
        workItemManager.completeWorkItem(workItem.getStringId(), java.util.Collections.singletonMap("flight", result));
    }

    public void abortWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
    }

    public String getName() {
        return "org.kie.kogito.examples.service.FlightService_addPassengerToFlight_16_Handler";
    }
}
